==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/kmlexport/kipiplugin_kmlexport.desktop.cmake <==
[Desktop Entry]
Comment=A plugin to create KML files to present images with coordinates.
Comment[bg]=Приставка за създаване на KML-файлове, представящи изображенията с координати.
Comment[ca]=Un connector per crear fitxers KML per presentar imatges amb coordenades.
Comment[ca@valencia]=Un connector per crear fitxers KML per presentar imatges amb coordenades.
Comment[cs]=Modul pro vytváření KML souborů k zobrazování snímků se souřadnicemi.
Comment[da]=Et plugin til at oprette KML-filer til at præsentere billeder med koordinater.
Comment[el]=Ένα πρόσθετο δημιουργίας αρχείων KML για την παρουσίαση εικόνων με συντεταγμένες.
Comment[en_GB]=A plugin to create KML files to present images with coordinates.
Comment[es]=Un complemento para crear archivos KML para presentar imágenes con coordenadas.
Comment[et]=Plugin KML-failide loomiseks, mis tähistavad koordinaatidega pilte.
Comment[gl]=Un engadido para crear ficheiros KML para presentar imaxes con coordenadas.
Comment[hu]=Egy bővítmény KML fájlok létrehozásához képek koordinátákkal való megjelenítéséhez.
Comment[is]=Íforrit til að búa til KML-skrár fyrir hnattstaðsetningu mynda.
Comment[it]=Un'estensione per creare file KML per presentare le immagini con coordinate.
Comment[km]=កម្មវិធី​ជំនួយ​សម្រាប់​បង្កើត​ឯកសារ​ KML ដើម្បី​បង្ហាញ​រូបភាព​ដោយ​មាន​ការសម្របសម្រួល ។
Comment[nb]=Et programtillegg for å lage KML-filer slik at bilder kan vises med koordinater.
Comment[nl]=Een plugin om KML-bestanden aan te maken om afbeeldingen met coördinaten te bieden.
Comment[pl]=Wtyczka do tworzenia plików KML do prezentacji obrazów ze współrzędnymi.
Comment[pt]=Um 'plugin' para criar ficheiros KML que apresentem imagens com coordenadas.
Comment[pt_BR]=Um plugin para criar arquivos KML que apresentem imagens com coordenadas.
Comment[ro]=O extensie de creat fișiere KML pentru prezentarea imaginilor cu coordonate.
Comment[sl]=Vstavek za ustvarjanje datotek KML, ki predstavijo sliko s koordinatami.
Comment[sv]=Ett insticksprogram för att skapa KML-filer som visar bilder med koordinater.
Comment[uk]=Додаток для створення файлів KML для показу зображення з координатами.
Comment[x-test]=xxA plugin to create KML files to present images with coordinates.xx
Comment[zh_TW]=建立 KML 檔來將影像展示在座標軸上的外掛程式。
Icon=applications-development-web
Name=KMLExport
Name[bg]=Изнасяне в KML
Name[ca]=KMLExport
Name[ca@valencia]=KMLExport
Name[cs]=KMLExport
Name[da]=KMLExport
Name[de]=KMLExport
Name[el]=KMLExport
Name[en_GB]=KMLExport
Name[es]=KMLExport
Name[et]=KML-i eksport
Name[ga]=KMLExport
Name[gl]=KMLExport
Name[hu]=KML exportálás
Name[is]=KMLÚtflutningur
Name[it]=Esportazione a KML
Name[km]=KMLExport
Name[nb]=KMLeksport
Name[nl]=KMLExport
Name[pl]=EksportDoKML
Name[pt]=KMLExport
Name[pt_BR]=Exportar para KML
Name[ro]=KMLExport
Name[ru]=Экспорт в KML
Name[sl]=KMLExport
Name[sv]=Export till KML
Name[uk]=KMLExport
Name[x-test]=xxKMLExportxx
Name[zh_CN]=KML导出
Name[zh_TW]=KML 匯出
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_kmlexport
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-3.1.0.tar.bz2: digikam-3.1.0/extra/kipi-plugins/kmlexport/kipiplugin_kmlexport.desktop.cmake <==
[Desktop Entry]
Comment=A plugin to create KML files to present images with coordinates.
Comment[bg]=Приставка за създаване на KML-файлове, представящи изображенията с координати.
Comment[bs]=Dodatak za kreiranje KML za predstavljanje slika s koordinatama.
Comment[ca]=Un connector per crear fitxers KML per presentar imatges amb coordenades.
Comment[ca@valencia]=Un connector per crear fitxers KML per presentar imatges amb coordenades.
Comment[cs]=Modul pro vytváření KML souborů k zobrazování snímků se souřadnicemi.
Comment[da]=Et plugin til at oprette KML-filer til at præsentere billeder med koordinater.
Comment[de]=Ein Modul zum Erstellen von KML-Dateien, um Bilder mit Koordinaten zu versehen.
Comment[el]=Ένα πρόσθετο δημιουργίας αρχείων KML για την παρουσίαση εικόνων με συντεταγμένες.
Comment[en_GB]=A plugin to create KML files to present images with coordinates.
Comment[es]=Un complemento para crear archivos KML para presentar imágenes con coordenadas.
Comment[et]=Plugin KML-failide loomiseks, mis tähistavad koordinaatidega pilte.
Comment[fr]=Un outil de création de fichiers KML pour présenter des images avec des coordonnées.
Comment[gl]=Un engadido para crear ficheiros KML para presentar imaxes con coordenadas.
Comment[hu]=Egy bővítmény KML fájlok létrehozásához képek koordinátákkal való megjelenítéséhez.
Comment[is]=Íforrit til að búa til KML-skrár fyrir hnattstaðsetningu mynda.
Comment[it]=Un'estensione per creare file KML per presentare le immagini con coordinate.
Comment[km]=កម្មវិធី​ជំនួយ​សម្រាប់​បង្កើត​ឯកសារ​ KML ដើម្បី​បង្ហាញ​រូបភាព​ដោយ​មាន​ការសម្របសម្រួល ។
Comment[nb]=Et programtillegg for å lage KML-filer slik at bilder kan vises med koordinater.
Comment[nl]=Een plugin om KML-bestanden aan te maken om afbeeldingen met coördinaten te bieden.
Comment[pl]=Wtyczka do tworzenia plików KML do prezentacji obrazów ze współrzędnymi.
Comment[pt]=Um 'plugin' para criar ficheiros KML que apresentem imagens com coordenadas.
Comment[pt_BR]=Um plugin para criar arquivos KML que apresentem imagens com coordenadas.
Comment[ro]=O extensie de creat fișiere KML pentru prezentarea imaginilor cu coordonate.
Comment[sl]=Vstavek za ustvarjanje datotek KML, ki predstavijo sliko s koordinatami.
Comment[sv]=Ett insticksprogram för att skapa KML-filer som visar bilder med koordinater.
Comment[uk]=Додаток для створення файлів KML для показу зображення з координатами.
Comment[x-test]=xxA plugin to create KML files to present images with coordinates.xx
Comment[zh_TW]=建立 KML 檔來將影像展示在座標軸上的外掛程式。
Icon=applications-development-web
UntranslatedGenericName=KMLExport
Name=KMLExport
Name[bg]=Изнасяне в KML
Name[bs]=KMLExport
Name[ca]=KMLExport
Name[ca@valencia]=KMLExport
Name[cs]=KMLExport
Name[da]=KMLExport
Name[de]=KMLExport
Name[el]=KMLExport
Name[en_GB]=KMLExport
Name[es]=KMLExport
Name[et]=KML-i eksport
Name[fr]=Export KML
Name[ga]=KMLExport
Name[gl]=KMLExport
Name[hu]=KML exportálás
Name[is]=KMLÚtflutningur
Name[it]=Esportazione a KML
Name[km]=KMLExport
Name[nb]=KMLeksport
Name[nl]=KMLExport
Name[pl]=EksportDoKML
Name[pt]=KMLExport
Name[pt_BR]=Exportar para KML
Name[ro]=KMLExport
Name[ru]=Экспорт в KML
Name[sl]=KMLExport
Name[sv]=Export till KML
Name[uk]=KMLExport
Name[x-test]=xxKMLExportxx
Name[zh_CN]=KML导出
Name[zh_TW]=KML 匯出
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_kmlexport
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
